/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
 *
 * Copyright (C) 2018 Tomas Bzatek <tbzatek@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __UDISKS_VDO_TYPES_H__
#define __UDISKS_VDO_TYPES_H__

#define VDO_MODULE_NAME "vdo"

struct _UDisksLinuxModuleVDO;
typedef struct _UDisksLinuxModuleVDO         UDisksLinuxModuleVDO;

typedef struct _UDisksLinuxManagerVDO        UDisksLinuxManagerVDO;
typedef struct _UDisksLinuxManagerVDOClass   UDisksLinuxManagerVDOClass;

typedef struct _UDisksLinuxBlockVDO          UDisksLinuxBlockVDO;
typedef struct _UDisksLinuxBlockVDOClass     UDisksLinuxBlockVDOClass;

#endif /* __UDISKS_VDO_TYPES_H__ */
